@@ -22,18 +22,19 @@
 
 #include "config.h"
 #include <errno.h>
+#include <limits.h>
 #include <poll.h>
+#include <stdarg.h>
+#include <stdbool.h>
+#include <stdint.h>
 #include <stdlib.h>
 #include <string.h>
-#include <limits.h>
 #include <unistd.h>
-#include <stdarg.h>
-#include <stdint.h>
-#include <stdbool.h>
 
-#include "libevdev.h"
 #include "libevdev-int.h"
 #include "libevdev-util.h"
+#include "libevdev.h"
+
 #include "event-names.h"
 
 #define MAXEVENTS 64
@@ -316,8 +317,7 @@ _libevdev_log_priority(const struct libevdev *dev)
 {
 	if (dev && dev->log.device_handler)
 		return dev->log.priority;
-	else
-		return libevdev_get_log_priority();
+	return libevdev_get_log_priority();
 }
 
 LIBEVDEV_EXPORT int
@@ -397,7 +397,9 @@ libevdev_set_fd(struct libevdev* dev, int fd)
 	if (dev->initialized) {
 		log_bug(dev, "device already initialized.\n");
 		return -EBADF;
-	} else if (fd < 0) {
+	}
+
+	if (fd < 0) {
 		return -EBADF;
 	}
 
@@ -869,11 +871,13 @@ read_more_events(struct libevdev *dev)
 
 	next = queue_next_element(dev);
 	len = read(dev->fd, next, free_elem * sizeof(struct input_event));
-	if (len < 0) {
+	if (len < 0)
 		return -errno;
-	} else if (len > 0 && len % sizeof(struct input_event) != 0) {
+
+	if (len > 0 && len % sizeof(struct input_event) != 0)
 		return -EINVAL;
-	} else if (len > 0) {
+
+	if (len > 0) {
 		int nev = len/sizeof(struct input_event);
 		queue_set_num_elements(dev, queue_num_elements(dev) + nev);
 	}
@@ -996,10 +1000,11 @@ update_mt_state(struct libevdev *dev, const struct input_event *e)
 		}
 
 		return 0;
-	} else if (dev->current_slot == -1) {
-		return 1;
 	}
 
+	if (dev->current_slot == -1)
+		return 1;
+
 	*slot_value(dev, dev->current_slot, e->code) = e->value;
 
 	return 0;
@@ -1103,7 +1108,9 @@ sanitize_event(const struct libevdev *dev,
 	   N to -1 or from -1 to N. Never from -1 to -1, or N to M. Very
 	   unlikely to ever happen from a real device.
 	   */
-	} else if (unlikely(sync_state == SYNC_NONE &&
+	}
+
+	if (unlikely(sync_state == SYNC_NONE &&
 			    dev->num_slots > -1 &&
 			    libevdev_event_is_code(ev, EV_ABS, ABS_MT_TRACKING_ID) &&
 			    ((ev->value == -1 &&
@@ -1131,10 +1138,11 @@ libevdev_next_event(struct libevdev *dev, unsigned int flags, struct input_event
 	if (!dev->initialized) {
 		log_bug(dev, "device not initialized. call libevdev_set_fd() first\n");
 		return -EBADF;
-	} else if (dev->fd < 0) {
-		return -EBADF;
 	}
 
+	if (dev->fd < 0)
+		return -EBADF;
+
 	if ((flags & valid_flags) == 0) {
 		log_bug(dev, "invalid flags %#x.\n", flags);
 		return -EINVAL;
@@ -1223,10 +1231,11 @@ libevdev_has_event_pending(struct libevdev *dev)
 	if (!dev->initialized) {
 		log_bug(dev, "device not initialized. call libevdev_set_fd() first\n");
 		return -EBADF;
-	} else if (dev->fd < 0) {
-		return -EBADF;
 	}
 
+	if (dev->fd < 0)
+		return -EBADF;
+
 	if (queue_num_elements(dev) != 0)
 		return 1;
 
@@ -1309,6 +1318,16 @@ libevdev_enable_property(struct libevdev *dev, unsigned int prop)
 	return 0;
 }
 
+LIBEVDEV_EXPORT int
+libevdev_disable_property(struct libevdev *dev, unsigned int prop)
+{
+	if (prop > INPUT_PROP_MAX)
+		return -1;
+
+	clear_bit(dev->props, prop);
+	return 0;
+}
+
 LIBEVDEV_EXPORT int
 libevdev_has_event_type(const struct libevdev *dev, unsigned int type)
 {
@@ -1405,9 +1424,9 @@ libevdev_fetch_event_value(const struct libevdev *dev, unsigned int type, unsign
 	    libevdev_has_event_code(dev, type, code)) {
 		*value = libevdev_get_event_value(dev, type, code);
 		return 1;
-	} else {
-		return 0;
 	}
+
+	return 0;
 }
 
 LIBEVDEV_EXPORT int
@@ -1457,9 +1476,9 @@ libevdev_fetch_slot_value(const struct libevdev *dev, unsigned int slot, unsigne
 	    slot < (unsigned int)dev->num_slots) {
 		*value = libevdev_get_slot_value(dev, slot, code);
 		return 1;
-	} else {
-		return 0;
 	}
+
+	return 0;
 }
 
 LIBEVDEV_EXPORT int
@@ -1646,10 +1665,11 @@ libevdev_kernel_set_abs_info(struct libevdev *dev, unsigned int code, const stru
 	if (!dev->initialized) {
 		log_bug(dev, "device not initialized. call libevdev_set_fd() first\n");
 		return -EBADF;
-	} else if (dev->fd < 0) {
-		return -EBADF;
 	}
 
+	if (dev->fd < 0)
+		return -EBADF;
+
 	if (code > ABS_MAX)
 		return -EINVAL;
 
@@ -1670,10 +1690,11 @@ libevdev_grab(struct libevdev *dev, enum libevdev_grab_mode grab)
 	if (!dev->initialized) {
 		log_bug(dev, "device not initialized. call libevdev_set_fd() first\n");
 		return -EBADF;
-	} else if (dev->fd < 0) {
-		return -EBADF;
 	}
 
+	if (dev->fd < 0)
+		return -EBADF;
+
 	if (grab != LIBEVDEV_GRAB && grab != LIBEVDEV_UNGRAB) {
 		log_bug(dev, "invalid grab parameter %#x\n", grab);
 		return -EINVAL;
@@ -1799,10 +1820,11 @@ libevdev_kernel_set_led_values(struct libevdev *dev, ...)
 	if (!dev->initialized) {
 		log_bug(dev, "device not initialized. call libevdev_set_fd() first\n");
 		return -EBADF;
-	} else if (dev->fd < 0) {
-		return -EBADF;
 	}
 
+	if (dev->fd < 0)
+		return -EBADF;
+
 	memset(ev, 0, sizeof(ev));
 
 	va_start(args, dev);
@@ -1856,9 +1878,10 @@ libevdev_set_clock_id(struct libevdev *dev, int clockid)
 	if (!dev->initialized) {
 		log_bug(dev, "device not initialized. call libevdev_set_fd() first\n");
 		return -EBADF;
-	} else if (dev->fd < 0) {
-		return -EBADF;
 	}
 
+	if (dev->fd < 0)
+		return -EBADF;
+
 	return ioctl(dev->fd, EVIOCSCLOCKID, &clockid) ? -errno : 0;
 }
