@@ -117,6 +117,14 @@ START_TEST(test_event_codes)
 			continue;
 		}
 
+#ifdef __FreeBSD__
+		/* Force feedback events are not supported by FreeBSD */
+		if (*evbit == EV_FF) {
+			evbit++;
+			continue;
+		}
+#endif
+
 		max = libevdev_event_type_get_max(*evbit);
 
 		for (code = 1; code < max; code += 10) {
@@ -305,6 +313,13 @@ START_TEST(test_set_input_props)
 	ck_assert_int_eq(libevdev_has_property(dev, INPUT_PROP_DIRECT), 0);
 	ck_assert_int_eq(libevdev_has_property(dev, INPUT_PROP_BUTTONPAD), 1);
 
+	/* Test disabling the properties too */
+	ck_assert_int_eq(libevdev_disable_property(dev, INPUT_PROP_MAX + 1), -1);
+	ck_assert_int_eq(libevdev_disable_property(dev, INPUT_PROP_DIRECT), 0);
+	ck_assert_int_eq(libevdev_disable_property(dev, INPUT_PROP_BUTTONPAD), 0);
+	ck_assert_int_eq(libevdev_has_property(dev, INPUT_PROP_DIRECT), 0);
+	ck_assert_int_eq(libevdev_has_property(dev, INPUT_PROP_BUTTONPAD), 0);
+
 	uinput_device_free(uidev);
 	libevdev_free(dev);
 }
