@@ -23,16 +23,16 @@
 
 #include "config.h"
 
-#include <sys/signalfd.h>
 #include <errno.h>
 #include <fcntl.h>
+#include <libgen.h>
 #include <limits.h>
 #include <math.h>
 #include <poll.h>
 #include <signal.h>
 #include <stdint.h>
-#include <stdlib.h>
 #include <stdio.h>
+#include <stdlib.h>
 #include <string.h>
 #include <unistd.h>
 
@@ -41,9 +41,11 @@
 #define min(a, b) (((a) < (b)) ? (a) : (b))
 #define max(a, b) (((a) > (b)) ? (a) : (b))
 
+static int signalled = 0;
+
 static int
-usage(void) {
-	printf("Usage: %s 12x34 /dev/input/eventX\n", program_invocation_short_name);
+usage(const char *progname) {
+	printf("Usage: %s 12x34 /dev/input/eventX\n", progname);
 	printf("\n");
 	printf("This tool reads the touchpad events from the kernel and calculates\n "
 	       "the minimum and maximum for the x and y coordinates, respectively.\n"
@@ -81,9 +83,10 @@ print_current_values(const struct dimensions *d)
 
 static int
 handle_event(struct dimensions *d, const struct input_event *ev) {
-	if (ev->type == EV_SYN) {
+	if (ev->type == EV_SYN)
 		return print_current_values(d);
-	} else if (ev->type != EV_ABS)
+
+	if (ev->type != EV_ABS)
 		return 0;
 
 	switch(ev->code) {
@@ -102,26 +105,26 @@ handle_event(struct dimensions *d, const struct input_event *ev) {
 	return 0;
 }
 
+static void
+signal_handler(__attribute__((__unused__)) int signal)
+{
+	signalled++;
+}
+
 static int
 mainloop(struct libevdev *dev, struct dimensions *dim) {
-	struct pollfd fds[2];
-	sigset_t mask;
+	struct pollfd fds;
 
-	fds[0].fd = libevdev_get_fd(dev);
-	fds[0].events = POLLIN;
+	fds.fd = libevdev_get_fd(dev);
+	fds.events = POLLIN;
 
-	sigemptyset(&mask);
-	sigaddset(&mask, SIGINT);
-	fds[1].fd = signalfd(-1, &mask, SFD_NONBLOCK);
-	fds[1].events = POLLIN;
+	signal(SIGINT, signal_handler);
 
-	sigprocmask(SIG_BLOCK, &mask, NULL);
-
-	while (poll(fds, 2, -1)) {
+	while (poll(&fds, 1, -1)) {
 		struct input_event ev;
 		int rc;
 
-		if (fds[1].revents)
+		if (signalled)
 			break;
 
 		do {
@@ -129,12 +132,16 @@ mainloop(struct libevdev *dev, struct dimensions *dim) {
 			if (rc == LIBEVDEV_READ_STATUS_SYNC) {
 				fprintf(stderr, "Error: cannot keep up\n");
 				return 1;
-			} else if (rc != -EAGAIN && rc < 0) {
+			}
+
+			if (rc != -EAGAIN && rc < 0) {
 				fprintf(stderr, "Error: %s\n", strerror(-rc));
 				return 1;
-			} else if (rc == LIBEVDEV_READ_STATUS_SUCCESS) {
-				handle_event(dim, &ev);
+
 			}
+
+			if (rc == LIBEVDEV_READ_STATUS_SUCCESS)
+				handle_event(dim, &ev);
 		} while (rc != -EAGAIN);
 	}
 
@@ -168,8 +175,6 @@ dmi_matchstr(struct libevdev *dev, char *match, size_t sz)
 
 	modalias[strlen(modalias) - 1] = '\0'; /* drop \n */
 	snprintf(match, sz, "name:%s:%s", libevdev_get_name(dev), modalias);
-
-	return;
 }
 
 static void
@@ -235,11 +240,11 @@ int main (int argc, char **argv) {
 	struct size size;
 
 	if (argc < 3)
-		return usage();
+		return usage(basename(argv[0]));
 
 	if (sscanf(argv[1], "%dx%d", &size.w, &size.h) != 2 ||
 	    size.w <= 0 || size.h <= 0)
-		return usage();
+		return usage(basename(argv[0]));
 
 	if (size.w < 30 || size.h < 30) {
 		fprintf(stderr,
@@ -251,7 +256,7 @@ int main (int argc, char **argv) {
 
 	path = argv[2];
 	if (path[0] == '-')
-		return usage();
+		return usage(basename(argv[0]));
 
 	fd = open(path, O_RDONLY|O_NONBLOCK);
 	if (fd < 0) {
